==> contraptions-3.10.2.tar.gz: contraptions-3.10.2/setup.py <==
#!/usr/bin/env python

"""The setup script."""
import sys

import semantic_release
import contraptions

from setuptools import setup, find_packages

with open("README.rst") as readme_file:
    readme = readme_file.read()

with open("HISTORY.rst") as history_file:
    history = history_file.read()

requirements = []

setup_requirements = ["pytest-runner"]

test_requirements = ["pytest>=3"]

setup(
    author="Ryan Fleck",
    author_email="Ryan.Fleck@protonmail.com",
    python_requires=">=3.5",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    description="Contraptions is a collection of algorithms and utilities used in my personal py-projects.",
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description=readme + "\n\n" + history,
    include_package_data=True,
    keywords="contraptions",
    name="contraptions",
    packages=find_packages(include=["contraptions", "contraptions.*"]),
    setup_requires=setup_requirements,
    test_suite="tests",
    tests_require=test_requirements,
    url="https://github.com/RyanFleck/contraptions",
    version=contraptions.__version__,
    zip_safe=False,
)

try:
    from semantic_release import setup_hook

    setup_hook(sys.argv)
except ImportError:
    pass

==> contraptions-3.10.3.tar.gz: contraptions-3.10.3/setup.py <==
#!/usr/bin/env python

"""The setup script."""
import sys

import semantic_release
import contraptions

from setuptools import setup, find_packages

with open("README.rst") as readme_file:
    readme = readme_file.read()

with open("CHANGELOG.md") as history_file:
    history = history_file.read()

requirements = []

setup_requirements = ["pytest-runner"]

test_requirements = ["pytest>=3"]

setup(
    author="Ryan Fleck",
    author_email="Ryan.Fleck@protonmail.com",
    python_requires=">=3.5",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    description="Contraptions is a collection of algorithms and utilities used in my personal py-projects.",
    install_requires=requirements,
    license="GNU General Public License v3",
    long_description=readme + "\n\n" + history,
    include_package_data=True,
    keywords="contraptions",
    name="contraptions",
    packages=find_packages(include=["contraptions", "contraptions.*"]),
    setup_requires=setup_requirements,
    test_suite="tests",
    tests_require=test_requirements,
    url="https://github.com/RyanFleck/contraptions",
    version=contraptions.__version__,
    zip_safe=False,
)

try:
    from semantic_release import setup_hook

    setup_hook(sys.argv)
except ImportError:
    pass
